@@ -1,6 +1,6 @@
 /* Yash: yet another shell */
 /* alias.c: alias substitution */
-/* (C) 2007-2011 magicant */
+/* (C) 2007-2012 magicant */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -502,30 +502,6 @@ int alias_builtin(int argc, void **argv)
     return (yash_error_message_count == 0) ? Exit_SUCCESS : Exit_FAILURE;
 }
 
-#if YASH_ENABLE_HELP
-const char *alias_help[] = { Ngt(
-"alias - define or print aliases\n"
-), Ngt(
-"\talias [-gp] [name[=value]...]\n"
-), Ngt(
-"The alias built-in defines and/or prints aliases.\n"
-), Ngt(
-"For each operand of the form <name=value>, an alias is (re)defined.\n"
-), Ngt(
-"If the -g (--global) option is specified, it is defined as a global alias,\n"
-"which is substituted even if it is not a command word.\n"
-), Ngt(
-"For each operand of the form <name>, the alias definition is printed.\n"
-), Ngt(
-"If the -p (--prefix) option is specified, the output format is suitable for\n"
-"re-input to the shell.\n"
-), Ngt(
-"If no operands are given, all alias definitions are printed.\n"
-), Ngt(
-"No options are available in the POSIXly correct mode.\n"
-), NULL };
-#endif
-
 /* The "unalias" built-in, which accepts the following option:
  *  -a: remove all aliases */
 int unalias_builtin(int argc, void **argv)
@@ -567,18 +543,5 @@ print_usage:
     return Exit_ERROR;
 }
 
-#if YASH_ENABLE_HELP
-const char *unalias_help[] = { Ngt(
-"unalias - undefine aliases\n"
-), Ngt(
-"\tunalias name...\n"
-"\tunalias -a\n"
-), Ngt(
-"The unalias built-in removes the specified alias definitions.\n"
-), Ngt(
-"If the -a (--all) option is specified, all definitions are removed.\n"
-), NULL };
-#endif
-
 
 /* vim: set ts=8 sts=4 sw=4 noet tw=80: */
