@@ -1,6 +1,6 @@
 /* Yash: yet another shell */
 /* printf.c: the echo/printf built-ins */
-/* (C) 2007-2011 magicant */
+/* (C) 2007-2012 magicant */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -262,77 +262,6 @@ print_char:
     return PR_OK;
 }
 
-#if YASH_ENABLE_HELP
-const char *echo_help[] = { Ngt(
-"echo - print arguments\n"
-), Ngt(
-"\techo [string...]\n"
-), Ngt(
-"The echo built-in prints <string>s followed by a newline to the standard\n"
-"output. The <string>s are each separated by a space. This built-in does not\n"
-"recognize any options except described below.\n"
-), (
-"\n"
-), Ngt(
-"The behavior of the echo built-in depends on the value of $ECHO_STYLE:\n"
-), Ngt(
-"  `SYSV' or `XSI' (default)\n"
-"    always recognize escape sequences but not any options.\n"
-), Ngt(
-"  `BSD'\n"
-"    recognize the -n option only.\n"
-), Ngt(
-"  `GNU'\n"
-"    recognize the -n, -e, -E options. Escape sequences are recognized if\n"
-"    enabled by the -e option.\n"
-), Ngt(
-"  `ZSH'\n"
-"    recognize the -n, -e, -E options. Escape sequences are recognized unless\n"
-"    disabled by the -E option.\n"
-), Ngt(
-"  `DASH'\n"
-"    recognize the -n option and escape sequences. Escape sequences cannot be\n"
-"    disabled.\n"
-), Ngt(
-"  `RAW'\n"
-"    do not recognize any options nor escape sequences.\n"
-), (
-"\n"
-), Ngt(
-"Options:\n"
-), Ngt(
-"  -n     do not print the last newline.\n"
-), Ngt(
-"  -e     enable escape sequences.\n"
-), Ngt(
-"  -E     disable escape sequences.\n"
-), (
-"\n"
-), Ngt(
-"Escape sequences:\n"
-), Ngt(
-"  \\a     alert (bell)\n"
-), Ngt(
-"  \\b     backspace\n"
-), Ngt(
-"  \\c     print nothing more\n"
-), Ngt(
-"  \\f     form feed\n"
-), Ngt(
-"  \\n     newline\n"
-), Ngt(
-"  \\r     carriage return\n"
-), Ngt(
-"  \\t     tab\n"
-), Ngt(
-"  \\v     vertical tab\n"
-), Ngt(
-"  \\\\     backslash\n"
-), Ngt(
-"  \\0nnn  8-bit value of the octal number <nnn>.\n"
-), NULL };
-#endif /* YASH_ENABLE_HELP */
-
 
 /* The "printf" built-in. */
 int printf_builtin(int argc, void **argv)
@@ -817,93 +746,5 @@ void freeformat(struct format_T *f)
     }
 }
 
-#if YASH_ENABLE_HELP
-const char *printf_help[] = { Ngt(
-"printf - print a formatted string\n"
-), Ngt(
-"\tprintf format [value...]\n"
-), /* xgettext:no-c-format */ Ngt(
-"The printf built-in prints a string formatted by <format>.\n"
-"This built-in is very similar to the C programming language's `printf'\n"
-"function. Each conversion specification starting with `%' in <format> is\n"
-"substituted with the value of the corresponding <argument>. Escape sequences\n"
-"starting with `\\' are also recognized.\n"
-), Ngt(
-"If there are more <argument>s than specified in <format>, formatted strings\n"
-"are repeatedly printed until all <argument>s are consumed. If there are\n"
-"insufficient <argument>s, an empty string or a value of zero is assumed for\n"
-"the missing arguments.\n"
-), (
-"\n"
-), Ngt(
-"Conversion specifications:\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %d    signed decimal integer\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %i    signed decimal integer\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %u    unsigned decimal integer\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %o    unsigned octal integer\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %x    unsigned hexadecimal integer (lowercase)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %X    unsigned hexadecimal integer (uppercase)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %f    floating point number (lowercase)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %F    floating point number (uppercase)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %e    floating point number with exponent (lowercase)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %E    floating point number with exponent (uppercase)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %g    %f or %e, automatically selected\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %G    %F or %E, automatically selected\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %c    first character of string\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %s    string\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %b    string (escape sequences are recognized like by the echo built-in)\n"
-), /* xgettext:no-c-format */ Ngt(
-"  %%    %\n"
-), (
-"\n"
-), /* xgettext:no-c-format */ Ngt(
-"Flags, field width, and precision can be specified in this order between\n"
-"`%' and the conversion specifier. For example, `%08.3f' is a specifier for a\n"
-"floating point number with the `0' flag, the field width of 8, and the\n"
-"precision of 3.\n"
-), (
-"\n"
-), Ngt(
-"Escape sequences:\n"
-), Ngt(
-"  \\a     alert (bell)\n"
-), Ngt(
-"  \\b     backspace\n"
-), Ngt(
-"  \\f     form feed\n"
-), Ngt(
-"  \\n     newline\n"
-), Ngt(
-"  \\r     carriage return\n"
-), Ngt(
-"  \\t     tab\n"
-), Ngt(
-"  \\v     vertical tab\n"
-), Ngt(
-"  \\\\     backslash\n"
-), Ngt(
-"  \\\"     double-quote\n"
-), Ngt(
-"  \\'     single-quote\n"
-), Ngt(
-"  \\nnn   8-bit value of the octal number <nnn>.\n"
-), NULL };
-#endif /* YASH_ENABLE_HELP */
-
 
 /* vim: set ts=8 sts=4 sw=4 noet tw=80: */
