@@ -1,6 +1,6 @@
 /* Yash: yet another shell */
 /* test.c: test builtin */
-/* (C) 2007-2011 magicant */
+/* (C) 2007-2012 magicant */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -668,148 +668,5 @@ enum filecmp compare_files(const wchar_t *left, const wchar_t *right)
 	return FC_SAME;
 }
 
-#if YASH_ENABLE_HELP
-const char *test_help[] = { Ngt(
-"test - evaluate a conditional expression\n"
-), Ngt(
-"\ttest expression\n"
-"\t[ expression ]\n"
-), Ngt(
-"The test built-in evaluates <expression> as a conditional expression\n"
-"described below. The exit status is 0 if the condition is true, or 1\n"
-"otherwise.\n"
-), (
-"\n"
-), Ngt(
-"Unary operators to test a file:\n"
-), Ngt(
-"  -b file    <file> is a block special file\n"
-), Ngt(
-"  -c file    <file> is a character special file\n"
-), Ngt(
-"  -d file    <file> is a directory\n"
-), Ngt(
-"  -e file    <file> exists\n"
-), Ngt(
-"  -f file    <file> is a regular file\n"
-), Ngt(
-"  -G file    <file>'s group ID is same as the shell's group ID\n"
-), Ngt(
-"  -g file    <file>'s set-group-ID flag is set\n"
-), Ngt(
-"  -h file    same as -L\n"
-), Ngt(
-"  -k file    <file>'s sticky bit is set\n"
-), Ngt(
-"  -L file    <file> is a symbolic link\n"
-), Ngt(
-"  -N file    <file> has not been accessed since last modified\n"
-), Ngt(
-"  -O file    <file>'s user ID is same as the shell's user ID\n"
-), Ngt(
-"  -p file    <file> is a FIFO (named pipe)\n"
-), Ngt(
-"  -r file    <file> is readable\n"
-), Ngt(
-"  -S file    <file> is a socket\n"
-), Ngt(
-"  -s file    <file> is not empty\n"
-), Ngt(
-"  -u file    <file>'s set-user-ID flag is set\n"
-), Ngt(
-"  -w file    <file> is writable\n"
-), Ngt(
-"  -x file    <file> is executable\n"
-), Ngt(
-"Unary operator to test a file descriptor:\n"
-), Ngt(
-"  -t fd      <fd> is associated with a terminal\n"
-), Ngt(
-"Unary operators to test a string:\n"
-), Ngt(
-"  -n string    <string> is not empty\n"
-), Ngt(
-"  -z string    <string> is empty\n"
-), (
-"\n"
-), Ngt(
-"Binary operators to compare files:\n"
-), Ngt(
-"  file1 -nt file2       <file1> is newer than <file2>\n"
-), Ngt(
-"  file1 -ot file2       <file1> is older than <file2>\n"
-), Ngt(
-"  file1 -ef file2       <file1> is a hard link to <file2>\n"
-), Ngt(
-"Binary operators to compare strings:\n"
-), Ngt(
-"  string1 = string2     <string1> is the same string as <string2>\n"
-), Ngt(
-"  string1 != string2    <string1> is not the same string as <string2>\n"
-), Ngt(
-"Binary operators to compare strings according to the current locale:\n"
-), Ngt(
-"  string1 === string2   <string1> is equal to <string2>\n"
-), Ngt(
-"  string1 !== string2   <string1> is not equal to <string2>\n"
-), Ngt(
-"  string1 < string2     <string1> is less than <string2>\n"
-), Ngt(
-"  string1 <= string2    <string1> is less then or equal to <string2>\n"
-), Ngt(
-"  string1 > string2     <string1> is greater than <string2>\n"
-), Ngt(
-"  string1 >= string2    <string1> is greater then or equal to <string2>\n"
-), Ngt(
-"Binary operators to compare integers:\n"
-), Ngt(
-"  v1 -eq v2    <v1> is equal to <v2>\n"
-), Ngt(
-"  v1 -ne v2    <v1> is not equal to <v2>\n"
-), Ngt(
-"  v1 -gt v2    <v1> is greater than <v2>\n"
-), Ngt(
-"  v1 -ge v2    <v1> is greater than or equal to <v2>\n"
-), Ngt(
-"  v1 -lt v2    <v1> is less than <v2>\n"
-), Ngt(
-"  v1 -le v2    <v1> is less than or equal to <v2>\n"
-), Ngt(
-"Binary operators to compare version numbers:\n"
-), Ngt(
-"  v1 -veq v2    <v1> is equal to <v2>\n"
-), Ngt(
-"  v1 -vne v2    <v1> is not equal to <v2>\n"
-), Ngt(
-"  v1 -vgt v2    <v1> is greater than <v2>\n"
-), Ngt(
-"  v1 -vge v2    <v1> is greater than or equal to <v2>\n"
-), Ngt(
-"  v1 -vlt v2    <v1> is less than <v2>\n"
-), Ngt(
-"  v1 -vle v2    <v1> is less than or equal to <v2>\n"
-), (
-"\n"
-), Ngt(
-"Operators to make complex expressions:\n"
-), Ngt(
-"  ! exp           negate (reverse) the result\n"
-), Ngt(
-"  ( exp )         change operator precedence\n"
-), Ngt(
-"  exp1 -a exp2    logical conjunction (and)\n"
-), Ngt(
-"  exp1 -o exp2    logical disjunction (or)\n"
-), Ngt(
-"Using these operators may cause confusion and should be avoided. Use the\n"
-"shell's compound commands.\n"
-), (
-"\n"
-), Ngt(
-"If the expression is a single word without operators, the -n operator is\n"
-"assumed. An empty expression evaluates to false.\n"
-), NULL };
-#endif /* YASH_ENABLE_HELP */
-
 
 /* vim: set ts=8 sts=4 sw=4 noet tw=80: */
