@@ -1,6 +1,6 @@
 /* Yash: yet another shell */
 /* ulimit.c: ulimit builtin */
-/* (C) 2007-2011 magicant */
+/* (C) 2007-2012 magicant */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <sys/time.h>
 #include <sys/resource.h>
 #include <wchar.h>
 #include <wctype.h>
@@ -35,6 +36,8 @@
 #include "ulimit.h"
 /* Including <stdint.h> is required before including <sys/resource.h> on
  * FreeBSD, but <stdint.h> is automatically included in <inttypes.h>. */
+/* On old Mac OS X, <sys/resource.h> depends on but does not include
+ * <sys/time.h>. We have to include it manually. */
 
 #if !HAVE_RLIM_SAVED_MAX
 # define RLIM_SAVED_MAX RLIM_INFINITY
@@ -100,8 +103,10 @@ static const struct xgetopt_T ulimit_options[] = {
     { L'u', L"nproc", OPTARG_NONE, true,
 	&RES(RLIMIT_NPROC, 1, Ngt("user processes")), },
 #endif
+#if HAVE_RLIMIT_AS
     { L'v', L"as", OPTARG_NONE, true,
 	&RES(RLIMIT_AS, 1024, Ngt("memory (kbytes)")), },
+#endif
 #if HAVE_RLIMIT_LOCKS
     { L'x', L"locks", OPTARG_NONE, true,
 	&RES(RLIMIT_LOCKS, 1, Ngt("file locks")), },
@@ -246,78 +251,5 @@ print_usage:
     return Exit_ERROR;
 }
 
-#if YASH_ENABLE_HELP
-const char *ulimit_help[] = { Ngt(
-"ulimit - set or print a resource limitation\n"
-), Ngt(
-"\tulimit [-HSaefilnqrstuvx] [limit]\n"
-), Ngt(
-"The ulimit built-in sets a resource limit to <limit>. The resource type can\n"
-"be specified by the options listed below.\n"
-), Ngt(
-"Each resource type has two limit values: the hard limit and the soft limit.\n"
-"You can change a soft limit freely as long as it does not exceed the hard\n"
-"limit. You can decrease a hard limit but cannot increase it without a proper\n"
-"permission. <limit> must be a non-negative integer or one of `hard', `soft',\n"
-"and `unlimited'.\n"
-), Ngt(
-"The resource limits will affect the current shell process and all commands\n"
-"invoked from the shell.\n"
-), Ngt(
-"If <limit> is not specified, the current limit is printed.\n"
-), Ngt(
-"Available options are:\n"
-), Ngt(
-" -H --hard\n"
-"\tSet or print the hard limit only.\n"
-), Ngt(
-" -S --soft\n"
-"\tSet or print the soft limit only.\n"
-), Ngt(
-"\tIf neither -H nor -S is specified, both the hard and soft limits are\n"
-"\tset (if <limit> is specified) or only the soft limit is printed (if\n"
-"\t<limit> is not specified).\n"
-), Ngt(
-" -a --all\n"
-"\tPrint all available resource types with the current limits.\n"
-), Ngt(
-"The following options can be used to specify the resource type:\n"
-), Ngt(
-" -c --core:       The maximum size of core files created (B)\n"
-), Ngt(
-" -d --data:       The maximum size of a process's data segment (K)\n"
-), Ngt(
-" -e --nice:       The maximum scheduling priority (`nice')\n"
-), Ngt(
-" -f --fsize:      The maximum size of files created by a process (B)\n"
-), Ngt(
-" -i --sigpending: The maximum number of pending signals\n"
-), Ngt(
-" -l --memlock:    The maximum memory size that can be locked into RAM (K)\n"
-), Ngt(
-" -m --rss:        The maximum size of a process's resident set (K)\n"
-), Ngt(
-" -n --nofile:     The maximum file descriptor + 1\n"
-), Ngt(
-" -q --msgqueue:   The maximum size of POSIX message queues\n"
-), Ngt(
-" -r --rtprio:     The maximum real-time scheduling priority\n"
-), Ngt(
-" -s --stack:      The maximum size of a process's stack (K)\n"
-), Ngt(
-" -t --cpu:        The CPU time that can be used by a process (S)\n"
-), Ngt(
-" -u --nproc:      The maximum number of processes for a user\n"
-), Ngt(
-" -v --as:         The maximum size of memory used by a process (K)\n"
-), Ngt(
-" -x --locks:      The maximum number of file locks\n"
-), Ngt(
-"For resource types marked with (B), (K), and (S), the limits are set and\n"
-"printed in 512-byte blocks, kilobytes, and seconds, respectively.\n"
-"Available resource types vary depending on your system.\n"
-), NULL };
-#endif /* YASH_ENABLE_HELP */
-
 
 /* vim: set ts=8 sts=4 sw=4 noet tw=80: */
